@@ -1,4 +1,4 @@
-__version__ = "0.3.2"
+__version__ = "3.2.0"
 
 import argparse
 
@@ -10,15 +10,16 @@ from shinyutils.subcls import (
     build_subclass_object,
 )
 from shinyutils.argp import (
+    ClassType,
     comma_separated_ints,
+    KeyValuePairsType,
     LazyHelpFormatter,
     OutputFileType,
     OutputDirectoryType,
-    ClassType,
 )
 from shinyutils.logng import build_log_argp, conf_logging
 
-shiny_arg_parser = argparse.ArgumentParser(
-    usage=argparse.SUPPRESS, formatter_class=LazyHelpFormatter
-)
+shiny_arg_parser = argparse.ArgumentParser(formatter_class=LazyHelpFormatter)
 build_log_argp(shiny_arg_parser)
+conf_logging()
+MatWrap.configure()
