@@ -1,5 +1,6 @@
 """matwrap.py: wrapper around matplotlib."""
 import json
+import warnings
 from pkg_resources import resource_filename
 
 
@@ -79,7 +80,24 @@ class MatWrap:
         cls._ensure_conf()
         return cls._sns
 
+    @classmethod
+    def palette(cls):
+        return [
+            "#e41a1c",
+            "#6a3d9a",
+            "#d55e00",
+            "#34495e",
+            "#377eb8",
+            "#4daf4a",
+            "#95a5a6",
+            "#222222",
+        ]
+
     @staticmethod
     def set_size_tight(fig, size):
+        warnings.warn(
+            "constrained_layout is enabled by default: don't use tight_layout",
+            DeprecationWarning,
+        )
         fig.set_size_inches(*size)
         fig.tight_layout(pad=0, w_pad=0, h_pad=0)
